### Describe
	The data push service is mainly used to meet the needs of customers for secondary development of basic devices data. This function can realize the active push of devices location data, alarm data, event data, offline/online status data, and data issued by commands.
	1. First, you need to write a WEB API interface based on the POST method to receive the data forwarded by the server. Please refer to the client code example
	2. Configure the written WEBAPI address through the rule ->Create a new rule, and fill it into the client address, which corresponds to the full URL of the interface, such as: http://47.112.122.222:8080/revTerminalLocation
	3. After the rules are configured, they are expected to take effect automatically within 5 minutes. At this time, the device reports the data, and the system's push engine will forward the data to the configured client address.

### Rule Configuration
 The user can configure the data to be pushed by the specified company in the rule configuration interface. The user needs to configure the data type, client address and other information.
 If there is a message header restriction, you need to add the message header configuration. If not, you can ignore it.
![](/uploads/v6JulaLyFCJcAK4U/images/m_0a2c8fdcdd3d16eb4a0a060f0345d6ab_r.png)
![](/uploads/v6JulaLyFCJcAK4U/images/m_5aa21ee1d794b606bb3e18254c31e6e1_r.png)
### Data type specification
  #### 1.Positioning data
    Device positioning data, including Device ID, positioning time, longitude and latitude, speed, mileage and other information
  ##### JSON String Example
      {"assetId":"8022300001","longitude":0.0,"latitude":0.0,"speed":0,"direction":0,"mileage":16,"gpsTime":"2022-09-01T08:59:56Z",\"ksInfo\":\"null\","recvTime":"2022-09-01T08:59:56.964Z","locType":0,"cellSignal":19,"gnssSignal":0,"cells":"460,0,9383,220792647","battery":100,"voltage":"0.0","statusJson":"{\"lockBar\":-1,\"lockRope\":0,\"lockStatus\":0}","expandInfo":"{\"angle\":\"null\",\"backBattery\":\"null\",\"fuels\":\"-1,-1,-1\",\"humidity\":\"0\",\"lux\":\"0.0\",\"networkType\":\"0\",\"pressure\":\"0.0\",\"reportType\":\"0\",\"temperature\":\"-1000.0\"}"}
##### Json Field Description
|Parameter name | Type | Description|
|:-----  |:-----|-----|
|assetId |String|Device ID|
|longitude |Double|longitude(WGS-84)|
|latitude |Double|latitude(WGS-84)|
|speed |Integer|speed(km/h)|
|direction |Integer|direction(0~360)|
|mileage |Long|mileage(km)|
|gpsTime |String|Positioning time（UTC）|
|recvTime |String|Receiving time（UTC）|
|locType |Integer|Positioning type (0: no positioning; 1: GPS positioning; 2: base station positioning;3:Cells positioning)|
|cellSignal |Integer| GPRS signal|
|gnssSignal |Integer|Satellite signal |
|cells |String|Cell code data is displayed in MNC, MCC, LAC and CID formats|
|battery |Integer|Power, 255 indicates charging |
|voltage |String|Voltage(V) |
|statusJson |String|Lock/vehicle mounted status JSON (refer to the status JSON description below)|
|expandInfo |String|Extension information JSON (refer to the following extension information JSON description)|
|ksInfo |String|KS20A asset information JSON（refer to the following KS20A asset information JSON description）,eg:,"ksInfo":"{\"angVelocity\":21000.0,\"eleStatus\":0,\"eleValue\":3.48,\"humidity\":0,\"luminance1\":50,\"luminance2\":50,\"luminance3\":50,\"luminance4\":50,\"posture\":\"x:0;y:0;z:230\",\"shakeStatus\":1,\"subInfo\":{\"112408000035\":{\"dateTime\":\"2025-05-14T09:39:03Z\",\"humidity\":60.0,\"lux\":0.0,\"subId\":\"112408000035\",\"temperature\":29.3}},\"subLockId\":\"022408000000\",\"temperature\":36.0,\"vibrate\":0,\"volStatus\":0,\"volValue\":23.5}"|

##### Lock Status JSON Description
|Parameter name | Type | Description|
|:-----  |:-----|-----|
|lockRope |Integer|Rope locking status (1: pulling out; 0: inserting; - 1: none)|
|lockStatus |Integer|Lock status (0: Off; 1: On)|

##### Vehicle status JSON description
|Parameter name | Type | Description|
|:-----  |:-----|-----|
|acc |Integer|Engine switch status (1: On; 0: Off; 1: None)|
|fuelCut |Integer|State of oil cut-off electric switch (1: On; 0: Off; 1: None)|
|door |Integer|Door opening/closing status (1: open; 0: close; - 1: none)|
|engine |Integer|Engine status (1: On; 0: Off; 1: None)|

##### JSON description of extension information
|Parameter name | Type | Description|
|:-----  |:-----|-----|
|temperature |String|Temperature - 1000 means none, unit: ℃|
|humidity |String|Humidity, unit :%|
|fuels |String|Oil level value - 1 means none ("- 1, - 1, - 1")|
|fAcceleration |String|acceleration(formats:"x: 1; y: - 29; z: - 2903")|
|lux |float|Illuminance(lux)|
|pressure |float|pressure(pa)|
|posture |String|Posture (formats:"x: 1; y: - 29; z: - 2903")|
|fVoltage |Double|Voltage value(V)|
|backBattery |String|Backup battery ("55,3.88,0")|
|fReportType |Integer|Data type (0: real-time; 1: supplementary report; 2: alarm)|
|fNetworkType |Integer|Network type (0: unknown 1:1G 2:2G 3:3G 4:4G 5:5G)|


#####  JSON description of KS20A asset information
|Parameter name | Type | Description|
|:-----  |:-----|-----|
|temperature |double| Onboard temperature -1000 means none, unit: ℃|
humidity |Integer| humidity, unit :%|
|volStatus |Integer| Voltage status (0: Normal LED voltage 1: Overvoltage LED voltage 2: Undervoltage voltage) |
|volValue |double| Voltage value, unit :V|
|eleStatus |Integer| Current status 0: LED current normal 1: LED current overcurrent 2: Current undercurrent |
|eleValue |double| Current value, unit :A|
|pressure |float| Air pressure (pa)|
|shakeStatus |Integer|0: Stationary 1: Shaking |
|angVelocity |Long| Angular velocity, unit :mdps|
|posture |String| Posture x,y,z axis values |
|vibrate |Integer| Amplitude, unit :mg|
|subLockId |String| Lock controller ID|
|subLargeCharId |String| Large word controller ID|
|luminance1 |Integer| Luminance of white light, unit :%|
|luminance2 |Integer| Red light brightness, unit :%|
|luminance3 |Integer| Yellow light luminance, unit :%|
|luminance4 |Integer| Blue luminance, unit :%|
|subInfo  | Map < String, Object > | peripherals information, parameter values: {\ "112408000042 \" : {\ "dateTime \" : \ "the 2025-05-13 T09:55:25 Z \", \ "eventType \" : 1, \ "humidity \" : 54. 0, \ "lux \" : 0.0, \ "subId \" : \ "112408000042 \", \ "temperature \" : 28.9}} |

##### description of subInfo 
|Parameter name | Type | Description|
|:-----  |:-----|-----|
|subId |String| Peripheral ID|
|dateTime |String| Peripheral online time,UTC time |
|temperature |double| Temperature, unit :℃|
|humidity |Integer| humidity, unit :%|
|lux |double| Illuminance, unit :lux|

#### 2.Alarm data
    Alarm data generated by equipment, including equipment number, alarm type, alarm time, longitude and latitude, etc.
##### Push JSON Example
    {"assetId":"875011000025","alarmType":46,"dateTime":"2020-04-01T00:00:13Z","longitude":0.0,"latitude":0.0,"speed":0,"mileage":0,"cells":"0,0,0,0","describe":"","fileIndex":"1585699212"}
##### Json Field Description
|Parameter name | Type | Description|
|:-----  |:-----|-----|
|assetId |String|Device ID|
|alarmType |Integer|Alarm type (refer to the following description of alarm type)|
|dateTime |String|Time (UTC time)|
|longitude |Double|longitude(WGS-84)|
|latitude |Double|latitude(WGS-84)|
|speed |Integer|speed(km/h)|
|mileage |Long|mileage(km)|
|cells |String|Cell code data is displayed in MNC, MCC, LAC and CID formats|
|describe |String|alarm describe|
|fileIndex |String|Serial number of files|

#### Alarm Type Description：

|Alarm Type | Alarm Name|
|:----   |-----   |
|1|Speeding Alarm|
|2|Fatigue driving|
|3|Danger warning|
|4|GNSS module failure|
|5|GNSS antenna not connected or cut off|
|6|GNSS antenna short circuit|
|7|device main power supply under voltage|
|8|Power failure of device main power supply|
|9|device LCD or display failure|
|10|TTS module failure|
|11|Camera fault|
|12|IC card module failure|
|13|Speeding warning|
|15|Power failure|
|19|Overtime parking|
|23|Route deviation alarm|
|24|Vehicle VSS failure|
|26|Vehicle theft|
|27|Illegal vehicle ignition|
|28|Illegal vehicle displacement|
|29|Collision warning|
|30|Rollover warning|
|31|Illegal door opening alarm|
|32|Video signal loss alarm|
|33|Video signal blocking alarm|
|34|Storage unit failure alarm|
|35|Other video equipment fault alarm|
|36|Passenger train overload alarm|
|37|Abnormal driving behavior alarm|
|38|Video recording reaches storage threshold alarm|
|40|Lock rope cut|
|41|Vibration|
|42|Long-time unlocking|
|43|Unlock password error for 5 consecutive times|
|44|Swiping illegal RFID card|
|45|Low power|
|46|Back cover opened|
|47|Motor stuck|
|48|Enter fence alarm|
|49|Exit fence alarm|
|50|Enable backup battery|
|51|SOS|
|52|Towing alarm|
|54|Fuel level change alarm|
|55|Enter hot spot alarm|
|56|Exit hot spot alarm|
|57|Access road alarm|
|58|Exit road alarm|
|63|Temperature and humidity alarm|
|64|Forward collision alarm|
|65|Lane departure alarm|
|66|Too close distance alarm|
|67|Pedestrian collision alarm|
|68|Frequent lane change alarm|
|69|Road sign overrun alarm|
|70|Obstacle alarm|
|71|Road sign recognition events|
|72|Active capture event|
|73|Lane changing of solid line|
|74|Pedestrian monitoring in car aisle|
|92|Fatigue driving alarm|
|93|Call the police|
|94|Smoking alarm|
|95|Distracted driving alarm|
|96|Driver abnormal alarm|
|97|Auto capture events|
|98|Driver change event|
|99|Probe blocked|
|100|Overtime driving|
|101|Not wearing seat belt|
|102|Infrared blocking sunglasses failure|
|103|Hands off the steering wheel|
|104|Playing with phone|
|110|Tire pressure alarm|
|125|Rear approach alarm|
|126|Left rear approach alarm|
|127|Right rear approach alarm|
|131|Rapid acceleration|
|132|Emergency deceleration|
|133|Emergency turning|
|134|Idle alarm|
|135|Abnormal flameout|
|136|Neutral skid alarm|
|137|Engine overspeed|
|141|Overspeed|
|145|Excess load of vehicle|
|146|Excess load of road|
|151|Height limit alarm|
|160|Safety belt alarm|
|161|Emergency brake alarm|
|162|Neutral skating|
|163|GPRS reconnection|
|164|Dispatching panel connection|
|165|Dispatch panel disconnected|
|166|CANbus disconnection alarm|
|167|CANbus fault code upload alarm|
|168|Limit drive alarm|
|180|Host dismantling|
|190|Damage of upper cover|
|191|GPS antenna interference|
|192|Low power sleep alarm|
|193|Device exception|
|194|Unlock password error|
|195|Do not perform unlocking without positioning|
|196|No unlocking outside the fence|
|197|Attitude alarm|
|198|Slave sensor signal lost|
|199|Supervision status forbids unlocking|
|200|Main battery replacement|
|201|Self-check exception|
|202|not enough storage space|
|203|Lock bar bent|
|204|Chain saw off|
|205|lock bar missing|
|206|Forbidden to unlock in the sealed state|
|316|Light alarm|
|332|Pressure alarm|
|400|Idling alarm|
|402|Fence stop alarm|
|403|Out fence unlock|
|404|Departure delay warning|
|405|Departure delay alarm|
|406|Late warning|
|407|Late alarm|

#### 3.Event data
    Event data generated by Device, including Device ID, event type, time, longitude and latitude, etc.
##### Push JSON Example
    {"assetId":"795206001104","eventType":1,"unLockType":1,"dateTime":"2022-08-19T02:07:28Z","longitude":0.0,"latitude":0.0,"speed":0,"mileage":5,"cells":"460,0,10352,220726855","card":"0003116836","password":"","describe":"{"waybillGUID":"190db1a2-3df1-4857-b94e-ee5937334409","waybillNo":"45435345"}}
##### Json Field Description
|Parameter name | Type | Description|
|:-----  |:-----|-----|
|assetId |String|Device ID|
|eventType |Integer|Event type (refer to the following description of event type)|
|unLockType |Integer|Unlocking type, only for lock on/off events (1: swipe card to unlock 2: remote unlock 3: Bluetooth unlock 4: cut rope to unlock 5: SMS unlock 6: regional trigger)|
|dateTime |String|Time (UTC time)|
|longitude |Double|longitude(WGS-84)|
|latitude |Double|latitude(WGS-84)|
|speed |Integer|speed(km/h)|
|mileage |Long|mileage(km)|
|cells |String|Cell code data is displayed in MNC, MCC, LAC and CID formats|
|card |String|Swipe card No,only for lock products|
|password |String|unlock password,only for lock products|
|describe |String|Description information. For route analysising waybill events 13-18, the description will have a Json string value, showing the waybill unique identifier (waybillGUID) and waybill number(Declaration No.)|

##### Event Type Description：

|Event Type | Event Name|
|:----   |-----   |
|1|Unlock|
|2|Lock|
|3|Sealing of exit area|
|4|Unblock the entrance area|
|5|Open box(door)|
|6|Close box(door)|
|7|Bluetooth sealing|
|8|Bluetooth unblocking|
|9|Remote sealing|
|10|Remote unsealing|
|11|Snap photos|
|12|Timed shooting|
|13|leave the starting point|
|14|reach the destination|
|15|leave the destination|
|16|Complete the waybill|
|17|entry waypoint|
|18|leave waypoint|
|19|Pull out the locking rope / Press the unlocking button(JT705A/JT705C)|

#### 4.Command response data
    Command response data generated by the device, including device number, command type, time, and returned content information of the command.
##### Push JSON Example
    {"assetId":"742207000010","commandType":"BASE2","content":"[\"742207000010\",\"8\",\"001\",\"BASE\",\"2\",\"20220901081402\"]","dateTime":"2022-09-01T08:14:03.564Z"}
##### Json Field Description
|Parameter name | Type | Description|
|:-----  |:-----|-----|
|assetId |String|Device ID|
|commandType |String|Command type|
|content |String|Equipment response content|
|dateTime |String|Time (UTC time)|

#### 5.Slave lock(sensor)
     Slave Device positioning data, including Device ID, positioning time, longitude and latitude, speed, mileage and other information
  ##### JSON String Description
      {"assetId":"8012600005","longitude":113.92294,"latitude":22.670017,"speed":0,"direction":0,"gpsTime":"2023-12-07T08:30:31Z","recvTime":"2023-12-07T08:30:52.474Z","subGpsTime":"2023-12-07T08:29:50Z","battery":71,"voltage":"3.93","subAssetID":"E0171E0365","sensorType":4,"statusJson":"{\"lockRope\":0,\"gateway\":0}","locStatus":0,"locRope":0,"rssi":57,"temperature":-1000.0,"humidity":0,"eventType":6,"locTimes":5,"subGpsTimestamp":1701937790000}
##### JsonField Description
  |Parameter name | Type | Description|
|:-----  |:-----|-----|
|assetId |String|Device ID|
|longitude |Double|longitude(WGS-84)|
|latitude |Double|latitude(WGS-84)|
|speed |Integer|speed(km/h)|
|direction |Integer|direction(0~360)|
|mileage |Long|mileage(km)|
|gpsTime |String|Positioning time（UTC）|
|recvTime |String|Receiving time（UTC）|
|subAssetID |String|Slave Equipment No|
|subGpsTime |String|Slave Positioning time（UTC））|
|subGpsTimestamp |Long|Slave Positioning timestamp|
|battery |Integer|Slave Power |
|voltage |String|Slave voltage (V)|
|sensorType |Integer|Slave Type  1-JT126 , 4-JT709 , 5-JT801 , 6-JT802 |
|locStatus |Integer|Slave lock status  0-Off 1-On |
|locRope |Integer|Slave Rope locking status (1: pulling out 0: inserting - 1: none)  |
|rssi |Integer|RSSI |
|humidity |Integer|Slave Temperature - 1000 means none |
|temperature |double|Slave Humidity 0 means none |
|locTimes |Integer|Slave unlock times |
|eventType |Integer|Slave Event -1：none 0:Lock event 1:BLE unlock event 2:Open back cover waring 3:Lora unlock event 4:Lock rope cut warning 5:Key wake up event 6:Heartbeat packet 7：Charging report event 8/20:Pull out the lock rope event 9：RFID unlock event  10：Illegal RFID unlock warning  14：Sub lock signal lost warning 15：Valve closed event 16：Valve open event 17：Low battery warning 18：Anti-disassembly 19：Disassembly of electronic compartment 21：Lock rope insertion 22：Bluetooth connection 23：Open emergency storage warning 24：Close emergency storage warning 25：Valve abnormally open warning 26：Turn off the knob event 27：Turn on the knob event 28:Unlocking Error 29:Abnormal Motor  30:NFC trigger |
|statusJson |String|For 802 device status data (Json string), other types of device data can be ignored|

##### statusJson Field Description
"FStatusJson":"{\"bottomDisassembly\":0,\"emergencyKey\":0,\"lockMotor\":0,\"structuralDisassembly\":0,\"gateway\":0,\"lockValve\":0}"

|Parameter name | Type | Description|
|:-----  |:-----|-----|
|bottomDisassembly |Integer|bottom disassembly status,0:No disassembly，1:disassembly|
|emergencyKey |Integer|emergency key status 0：Seal up，1：Enable|
|lockMotor |lock motor status：0：Off，1：On|
|structuralDisassembly |Integer|structural disassembly status,0:No disassembly，1:disassembly|
|lockValve |Integer|Lock Valve status,0：Off，1：On|
|lockKnob |Integer|Lock Knob status，0：Off，1：On|
|lockRope |Integer|Rope locking status 0：inserting；1：pulling out|
|gateway |Integer|Meaningless, can be ignored|
 
### Push log report
After configuring the push rules, users can query the logs generated by the platform's active push in the push log to facilitate problem analysis.
![](/uploads/v6JulaLyFCJcAK4U/images/m_6265e58cad540df1e1e223833a97db63_r.png)